import os
import sys
import toml

from typing import Dict
from logging import getLogger
from pathlib import Path


log = getLogger(__name__)


def is_debug() -> bool:
    """If debug."""
    return 'true' in str(os.environ.get('DEBUG', '')).lower()


def is_testing():
    """If test in progress."""
    _loaded = sys.modules.keys()
    _py_test = '_pytest.python_path' in _loaded
    _unit = 'unittest' in _loaded
    return _py_test or _unit


def project_dir() -> Path:
    """Project dir."""
    _app_dir = os.environ.get('PROJECT_DIR')
    assert _app_dir, 'Set PROJECT_DIR variable'
    return Path(_app_dir)


def deploy_dir() -> Path:
    """Deploy dir."""
    return Path(project_dir()) / 'deploy'


def read_project_config() -> Dict:
    """Read project pyproject.toml."""
    try:
        with open(poetry_config_path.as_posix()) as _toml_conf:
            return toml.loads(_toml_conf.read())
    except Exception as _read_project_cfg_exc:
        log.exception(_read_project_cfg_exc)
        sys.exit(f'Poetry config error: {_read_project_cfg_exc}')


def get_version() -> str:
    """Get app version."""
    try:
        return poetry_config['tool']['poetry']['version']
    except Exception as _read_app_version:
        log.exception(_read_app_version)
        sys.exit(f'App version error: {_read_app_version}')


poetry_config_path: Path = Path(project_dir()) / 'pyproject.toml'

poetry_config: Dict = read_project_config()
