from typing import List
from enum import Enum
from pathlib import Path
from logging import getLogger

from .fn import deploy_dir


log = getLogger(__name__)


def get_locales() -> List[str]:
    """Returns list of available locales or eng one."""
    locales_path, locales = Path(deploy_dir()) / 'locales', ['en']
    try:
        with open(locales_path) as _locales_file:
            locales = _locales_file.readlines()
            locales = [_l.lstrip()[0:2] for _l in locales]
    except (FileExistsError, Exception) as _conf_exc:
        log.exception(f'Open config by path {locales_path}: {_conf_exc}')
    finally:
        return locales


Lang = Enum('Lang', {str(_l).lower(): str(_l).upper() for _l in get_locales()})
